#!/bin/sh

# Invoke this script either with "all" or "daq" arguments.

usage() {
    echo "Usage: $0 all|daq"
}

DM_SVN_URL=https://subversion.xray.aps.anl.gov/DataManagement

supportType=all
if [ ! -z "$1" ]; then
    supportType=$1
fi
if [ $supportType != "all" -a $supportType != "daq" ]; then
    usage
    exit 1
fi

MY_DIR=`dirname $0` && cd $MY_DIR && MY_DIR=`pwd`
if [ -z "${DM_ROOT_DIR}" ]; then
    DM_ROOT_DIR=$MY_DIR/..
fi
DM_SUPPORT_DIR=$DM_ROOT_DIR/../support
DM_DATA_DIR=$DM_ROOT_DIR/../data

execute() {
    echo "Executing: $@"
    eval "$@"
}

if [ ! -d $DM_SUPPORT_DIR ]; then
    echo "Creating new DM support directory $DM_SUPPORT_DIR."
    cd `dirname $DM_SUPPORT_DIR`
    execute svn co $DM_SVN_URL/support support
fi
cd $DM_SUPPORT_DIR
execute svn update
execute $DM_SUPPORT_DIR/bin/clean_support_all.sh
execute $DM_SUPPORT_DIR/bin/install_support_${supportType}.sh

if [ ! -d $DM_DATA_DIR ]; then
    echo "Creating data directory"
    mkdir -p "$DM_DATA_DIR"
fi



