/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package gov.anl.aps.dm.portal.controllers;

import gov.anl.aps.dm.portal.constants.RoleTypeName;
import gov.anl.aps.dm.portal.model.beans.RoleTypeFacade;
import gov.anl.aps.dm.portal.model.beans.UserInfoFacade;
import gov.anl.aps.dm.portal.model.entities.UserInfo;
import gov.anl.aps.dm.portal.utilities.CryptUtility;
import gov.anl.aps.dm.portal.utilities.LdapUtility;
import gov.anl.aps.dm.portal.utilities.SessionUtility;
import java.io.Serializable;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.inject.Named;
import org.apache.log4j.Logger;

/**
 * Login controller.
 */
@Named("loginController")
@SessionScoped
public class LoginController implements Serializable
{

    @EJB
    private UserInfoFacade userInfoFacade;

    @EJB
    private RoleTypeFacade roleTypeFacade;
    
    private String username = null;
    private String password = null;
    private boolean loggedIn = false;
    private UserInfo user = null;
    private boolean isAdmin;

    private static final Logger logger = Logger.getLogger(LoginController.class.getName());

    /**
     * Constructor.
     */
    public LoginController() {
    }

    /**
     * Get password.
     *
     * @return login password
     */
    public String getPassword() {
        return password;
    }

    /**
     * Set password.
     *
     * @param password login password
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * Get username.
     *
     * @return login username
     */
    public String getUsername() {
        return username;
    }

    /**
     * Set username.
     *
     * @param username login username
     */
    public void setUsername(String username) {
        this.username = username;
    }

    /**
     * Check if user is logged in.
     *
     * @return true if admin is logged in, false otherwise
     */
    public boolean isLoggedIn() {
        return loggedIn;
    }

    /**
     * Login action.
     *
     * @return url to service home page if login is successful, or null in case
     * of errors
     */
    public String login() {
        loggedIn = false;
        if (username == null || password == null || username.isEmpty() || password.isEmpty()) {
           SessionUtility.addWarningMessage(null, "Incomplete Input. Please enter both username and password.");
           return (username = password = null);
        }

        user = userInfoFacade.findByUsername(username);
        if (user == null) {
            SessionUtility.addErrorMessage(null, "Username " + username + " is not registered. Contact administrator.");
            return (username = password = null);
        }

        boolean validCredentials = false;
        if (user.getPassword() != null && CryptUtility.verifyPasswordWithPbkdf2(password, user.getPassword())) {
            logger.debug("User " + username + " is authorized by DM DB");
            validCredentials = true;
        }
        else if (LdapUtility.validateCredentials(username, password)) {
            logger.debug("User " + username + " is authorized by DM LDAP");
            validCredentials = true;
        }
        else {
            logger.debug("User " + username + " is not authorized.");
        }

        if (validCredentials) {
            SessionUtility.setUser(user);

            loggedIn = true;
            SessionUtility.addInfoMessage("Successful Login", "User " + username + " is logged in.");
            isAdmin = roleTypeFacade.findByName(RoleTypeName.ADMIN).isAdmin(username);
            return getLandingPage();
        }
        else {
             SessionUtility.addErrorMessage(null, "Invalid Credentials. Username/password combination could not be verified.");
             SessionUtility.addErrorMessage(null, "If you are having difficulty logging in, please see our <a href=\"/dm/views/loginHelp.xhtml\">login help</a> page.");
            return (username = password = null);
        }

    }
    
    public String getLandingPage() {
        String landingPage = SessionUtility.getCurrentViewId() + "?faces-redirect=true";
        if (landingPage.contains("login")) {
            landingPage = "/views/home?faces-redirect=true";
        }
        logger.debug("Landing page: " + landingPage);
        return landingPage;
    }
    
    public String displayUsername() {
        if (isLoggedIn()) {
            return username;
        }
        else {
            return "Not Logged In";
        }
    }

    public boolean isUserWriteable(UserInfo user) {
        if (!isLoggedIn()) {
            return false;
        }
        return isLoggedIn() || this.user.getId() == user.getId();
    }

    /**
     * Logout action.
     *
     * @return url to logout page
     */
    public String logout() {
        SessionUtility.clearSession();
        ExternalContext context = FacesContext.getCurrentInstance().getExternalContext();
        context.invalidateSession();
        loggedIn = false;
        user = null;
        return "/views/login?faces-redirect=true";
    }

        public boolean isAdmin() {
            return isAdmin;
    }


}
