#!/usr/bin/env python

from dm.cat_web_service.api.fileRestApi import FileRestApi
from dm.common.exceptions.invalidRequest import InvalidRequest
from catWebServiceSessionCli import CatWebServiceSessionCli

class GetExperimentFileCli(CatWebServiceSessionCli):
    def __init__(self):
        CatWebServiceSessionCli.__init__(self, validArgCount=self.ANY_NUMBER_OF_POSITIONAL_ARGS)
        self.addOption('', '--file', dest='fileName', help='File name.')
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')
        if self.options.fileName is None:
            raise InvalidRequest('File name must be provided.')

    def getExperimentName(self):
        return self.options.experimentName

    def getFileName(self):
        return self.options.fileName

    def runCommand(self):
        self.parseArgs(usage="""
    dm-get-experiment-file --file=FILENAME --experiment=EXPERIMENTNAME 

Description:
    Retrieve experiment file metadata from the catalog. 
        """)
        self.checkArgs()
        api = FileRestApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        fileMetadata = api.getExperimentFile(self.getExperimentName(), self.getFileName())
        print fileMetadata.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = GetExperimentFileCli()
    cli.run()

