#!/usr/bin/env python

from dm.cat_web_service.api.fileRestApi import FileRestApi
from dm.common.exceptions.invalidRequest import InvalidRequest
from catWebServiceSessionCli import CatWebServiceSessionCli

class GetExperimentFilesCli(CatWebServiceSessionCli):
    def __init__(self):
        CatWebServiceSessionCli.__init__(self, validArgCount=self.ANY_NUMBER_OF_POSITIONAL_ARGS)
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')

    def getExperimentName(self):
        return self.options.experimentName

    def runCommand(self):
        self.parseArgs(usage="""
    dm-get-experiment-files --experiment=EXPERIMENTNAME 
        [key1:value1, key2:value2, ...]

Description:
    Retrieve experiment files from the metadata catalog. Only those files that
    match provided key/value metadata pairs will be returned. If no specific
    metadata key/values are requested, all experiment files will be returned. 
        """)
        self.checkArgs()
        api = FileRestApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        queryDict = self.splitArgsIntoDict()
        fileMetadataList = api.getExperimentFiles(self.getExperimentName(), queryDict)
        for fileMetadata in fileMetadataList:
            print fileMetadata.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = GetExperimentFilesCli()
    cli.run()

