#!/usr/bin/env python

import cherrypy
import json
from dm.common.utility.encoder import Encoder
from dm.common.service.dmSessionController import DmSessionController
from dm.cat_web_service.service.impl.fileSessionControllerImpl import FileSessionControllerImpl

class FileSessionController(DmSessionController):

    def __init__(self):
        DmSessionController.__init__(self)
        self.fileSessionControllerImpl = FileSessionControllerImpl()

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def addExperimentFile(self, experimentName, fileName, **kwargs):
        if not experimentName:
            raise InvalidRequest('Invalid experiment name provided.')
        if not fileName:
            raise InvalidRequest('Invalid file name provided.')
        encodedFileInfo = kwargs.get('fileInfo')
        if not encodedFileInfo:
            raise InvalidRequest('Invalid file info provided.')
        fileInfo = json.loads(Encoder.decode(encodedFileInfo))
        fileInfo['fileName'] = fileName
        fileInfo['experimentName'] = experimentName
        response = self.fileSessionControllerImpl.addExperimentFile(fileInfo).getFullJsonRep()
        self.logger.debug('Added file %s: %s' % (fileName,response))
        return response

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def updateExperimentFile(self, experimentName, fileName, **kwargs):
        if not experimentName:
            raise InvalidRequest('Invalid experiment name provided.')
        if not fileName:
            raise InvalidRequest('Invalid file name provided.')
        encodedFileInfo = kwargs.get('fileInfo')
        if not encodedFileInfo:
            raise InvalidRequest('Invalid file info provided.')
        fileInfo = json.loads(Encoder.decode(encodedFileInfo))
        fileInfo['fileName'] = fileName
        fileInfo['experimentName'] = experimentName
        response = self.fileSessionControllerImpl.updateExperimentFile(fileInfo).getFullJsonRep()
        self.logger.debug('Updated file %s: %s' % (fileName,response))
        return response

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def updateFileById(self, id, **kwargs):
        if not id:
            raise InvalidRequest('Invalid file id provided.')
        encodedFileInfo = kwargs.get('fileInfo')
        if not encodedFileInfo:
            raise InvalidRequest('Invalid file info provided.')
        fileInfo = json.loads(Encoder.decode(encodedFileInfo))
        response = self.fileSessionControllerImpl.updateFileById(fileInfo).getFullJsonRep()
        self.logger.debug('Updated file id %s: %s' % (id,response))
        return response

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def getFiles(self, **kwargs):
        encodedQueryDict = kwargs.get('queryDict')
        queryDict = {}
        if encodedQueryDict:
            queryDict = json.loads(Encoder.decode(encodedQueryDict))
        return self.listToJson(self.fileSessionControllerImpl.getFiles(queryDict=queryDict))

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def getExperimentFiles(self, experimentName, **kwargs):
        if not experimentName:
            raise InvalidRequest('Invalid experiment name provided.')
        encodedQueryDict = kwargs.get('queryDict')
        queryDict = {}
        if encodedQueryDict:
            queryDict = json.loads(Encoder.decode(encodedQueryDict))
        return self.listToJson(self.fileSessionControllerImpl.getExperimentFiles(experimentName, queryDict=queryDict))

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def getFileById(self, id, **kwargs):
        if not id:
            raise InvalidRequest('Invalid id provided.')
        response = self.fileSessionControllerImpl.getFileById(id).getFullJsonRep()
        self.logger.debug('Returning file id %s: %s' % (id,response))
        return response

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def getExperimentFile(self, experimentName, fileName, **kwargs):
        if not experimentName:
            raise InvalidRequest('Invalid experiment name provided.')
        if not fileName:
            raise InvalidRequest('Invalid file name provided.')
        response = self.fileSessionControllerImpl.getExperimentFile(experimentName, fileName).getFullJsonRep()
        self.logger.debug('Returning file %s: %s' % (fileName,response))
        return response

