#!/usr/bin/env python

from daqWebServiceSessionCli import DaqWebServiceSessionCli
from dm.daq_web_service.api.experimentRestApi import ExperimentRestApi
from dm.common.exceptions.invalidRequest import InvalidRequest

class UploadCli(DaqWebServiceSessionCli):
    def __init__(self):
        DaqWebServiceSessionCli.__init__(self, validArgCount=self.ANY_NUMBER_OF_POSITIONAL_ARGS)
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')
        self.addOption('', '--data-directory', dest='dataDirectory', help='Experiment data directory.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')
        if self.options.dataDirectory is None:
            raise InvalidRequest('Experiment data directory must be provided.')

    def getExperimentName(self):
        return self.options.experimentName

    def getDataDirectory(self):
        return self.options.dataDirectory

    def runCommand(self):
        self.parseArgs(usage="""
    dm-upload --experiment=EXPERIMENTNAME --data-directory=DATADIRECTORY
        [key1:value1, key2:value2, ...]

Description:
    Schedules data upload for a given experiment. All existing files in the
    specified directory will be uploaded to storage. Relative directory 
    structure will be preserved. All provided key/value pairs will be passed 
    to file processing plugins.
        """)
        self.checkArgs()
        api = ExperimentRestApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        daqInfo = self.splitArgsIntoDict()
        experiment = api.upload(self.getExperimentName(), self.getDataDirectory(), daqInfo=daqInfo)
        print experiment.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = UploadCli()
    cli.run()

