#!/usr/bin/env python

import cherrypy
import json

from dm.common.service.dmSessionController import DmSessionController
from dm.common.exceptions.invalidRequest import InvalidRequest
from dm.common.utility.encoder import Encoder

from dm.ds_web_service.service.impl.fileSessionControllerImpl import FileSessionControllerImpl


class FileSessionController(DmSessionController):

    def __init__(self):
        DmSessionController.__init__(self)
        self.fileSessionControllerImpl = FileSessionControllerImpl()

    @cherrypy.expose
    @DmSessionController.require(DmSessionController.isAdministrator())
    @DmSessionController.execute
    def processFile(self, **kwargs):
        encodedFileInfo = kwargs.get('fileInfo')
        if not encodedFileInfo:
            raise InvalidRequest('Invalid file info provided.')
        fileInfo = json.loads(Encoder.decode(encodedFileInfo))

        if not fileInfo.has_key('experimentFilePath'):
            raise InvalidRequest('Experiment file path is missing.')
        if not fileInfo.has_key('experimentName'):
            raise InvalidRequest('Experiment name is missing.')
        response = self.fileSessionControllerImpl.processFile(fileInfo).getFullJsonRep()
        self.logger.debug('Returning: %s' % response)
        return response

